<?php 

namespace Woowa\Modules;

class ReminderOrder2 {

	/**
	 * set reminder order after checkout
	 * hooked via action woocommerce_thankyou, priority 10
	 * @param int $order_id
	 * @return void
	 */
	public function set_reminder_order_after_checkout( $order_id ) {

		if ( ! $order_id )
			return;
			
		// Allow code execution only once 
		if ( ! get_post_meta( $order_id, '_thankyou_action_done', true ) ) :

			$this->set_cron_action_scheduler( $order_id, 0 );

			update_post_meta( $order_id, '_thankyou_action_done', true );

		endif;

	}

	/**
	 * set cron action scheduler
	 * @param int $order_id
	 * @param int $kirim_wa_ke
	 * @return void
	 */
	public function set_cron_action_scheduler( $order_id, $kirim_wa_ke = 0 ) {

		$post = get_post( $order_id );

		if ( is_a( $post,'WP_Post' ) && $post->post_type === 'shop_order' ) :

			$batas_reminder = get_option("on_hold_reminder");
			if (empty($batas_reminder)) :
				$batas_reminder = 2;
			endif;
		
			$type = get_option("woowa_on_hold_reminder_type");
			if (empty($type)) :
				$type = "day";
			endif;
			
			$add_minutes = 0;
		
			switch ( $type ) {
				case 'day':
					$add_minutes = $batas_reminder*24*60;
					break;
		
				case 'hour':
					$add_minutes = $batas_reminder*60;
					break;
			}

			$timestamp = strtotime( 'now +'. $add_minutes .' minutes' );
			$hook = 'woowa_reminder_order_scheduler2';
			$args = [
				[
					'order_id' 		=> $order_id,
					'kirim_wa_ke'	=> $kirim_wa_ke,
				]
			];
			$group = 'woowa_scheduler';
	
			if ( false === as_next_scheduled_action( $hook, $args, $group ) ) :
				as_schedule_single_action( $timestamp, $hook, $args, $group );
			endif;

		endif;

	}

	/**
	 * send reminder order
	 * hooked via action woowa_reminder_order_scheduler, priority 10
	 * @param array $data
	 * @return void
	 */
	public function send_reminder_order( $data ) {

		$toggle_reminder_order = get_option('woowa_toggle_reminder_order');

		if ( isset( $data['order_id'] ) && $toggle_reminder_order === 'checked' ) :

			$order = wc_get_order( $data['order_id'] );

			if ( is_a( $order,'WC_Order' ) && in_array( $order->get_status(), ['on-hold','pending'] ) ) :

				woowa_sendapi( $order->get_id(),'reminder_order');

				if ( get_option('woowa_reminder_loop') ) :

					$i = get_post_meta( $order->get_id(), 'kirim_wa_ke', true );
					
					if ($i >= 3) :
						$ke = 3; 
					else : 
						$ke = $i+1;
					endif;

					update_post_meta( $order->get_id(),'kirim_wa_ke', $ke );

					if ( $i < 3 ) :
						$this->set_cron_action_scheduler( $order->get_id(), $ke );
					endif;
		
				endif;

			endif;

		endif;

	}

}